# Python Esbuild

[WIP]

A highly experimental Python wrapper for [Esbuild](https://esbuild.github.io/), an extremely fast JavaScript bundle.

Allows you to build modern JavaScript from Python without installing Node and bundlers like Webpack, Vite, Parcel,
etc...
